/*
    siu-sh7343.h - Alsa driver for Renesas' SH7343 SIU peripheral.

    Copyright (c) 2006 Carlos Munoz <carlos@kenati.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/


#ifndef SIU_SH7343_H
#define SIU_SH7343_H

extern const u_int32_t SIU_SPB_PRO_Y0[];
extern const u_int32_t SIU_SPB_PRO_Y1[];
extern const u_int32_t SIU_SPB_PRO_Y2[];
extern const u_int32_t SIU_SPB_PRO_Y3[];
extern const u_int32_t SIU_SPB_PRO_Y4[];
extern const u_int32_t SIU_SRC_44100_44100[];
extern double log10(double x);


#define MAX_SIU_PORTS		3
#define SIU_PORTA		0		/* port A */
#define SIU_PORTB		1		/* port B */
#define SIU_PORTC		2		/* melody */

#define PKCHKOFF		0x00000000	/* detect peak level by soft 
						   OFF */
#define GEQOFF			0x00000000	/* GEQ disable */
#define GEQON			0x00000001	/* GEQ enable */

/* driver status  states */
#define ST_STOP			0x00000000
#define ST_READY		0x00000001
#define ST_OPEN			0x00000004
#define ST_LPF_CALL		0x00000010	/* _lowpassfilter() call */
#define ST_SRC_CALL		0x00000020	/* _sampling_rate() call */
#define ST_SPE_CALL		0x00000040	/* _speed() call */
#define ST_IIR_CALL		0x00000200	/* _graphic_equalizer() call */
#define ST_PATHA_CALL		0x00000400	/* path A setting called */
#define ST_PATHB_CALL		0x00000800	/* path B setting called */
#define ST_SPBACTIV		0x00001000	/* SPB working */

/* SIU memory address definition */
#define siu_p_ram		0xa4540000	/* PRAM */
#define siu_x_ram		0xa4544000	/* XRAM */
#define siu_y_ram		0xa4546000	/* YRAM */
#define siu_fifo_ram		0xa4548000	/* FIFO RAM */

#define YRAM0_SIZE		(0x0040/4)	/* 16 */
#define YRAM1_SIZE		(0x0080/4)	/* 32 */
#define YRAM2_SIZE		(0x0040/4)	/* 16 */
#define YRAM3_SIZE		(0x0080/4)	/* 32 */
#define YRAM4_SIZE		(0x0080/4)	/* 32 */
#define YRAM_DEF_SIZE		(YRAM0_SIZE + YRAM1_SIZE + YRAM2_SIZE + \
                                 YRAM3_SIZE + YRAM4_SIZE)
#define YRAM_FIR_SIZE		(0x0400/4)	/* 256 */
#define YRAM_IIR_SIZE		(0x0200/4)	/* 128 */

#define XRAM0_SIZE		(0x0400/4)	/* 256 */
#define XRAM1_SIZE		(0x0200/4)	/* 128 */
#define XRAM2_SIZE		(0x0200/4)	/* 128 */


/* Register access */
#define IN8(addr)		(*((volatile u_int8_t *)(addr)))
#define IN16(addr)		(*((volatile u_int16_t *)(addr)))
#define IN32(addr)		(*((volatile u_int32_t *)(addr)))
#define OUT8(addr, val)		(*((volatile u_int8_t *)(addr)) = (val))
#define OUT16(addr, val)	(*((volatile u_int16_t *)(addr)) = (val))
#define OUT32(addr, val)	(*((volatile u_int32_t *)(addr)) = (val))

/* Pin function controller (PFC) registers */
#define PSELB			0xa405014e
#define PSELB_PSB0		0x0001
#define PSELB_PSB1		0x0002

#define PSELC			0xa4050150
#define PSELC_PSC15		0x8000
#define PSELC_PSC14		0x4000
#define PSELC_PSC13		0x2000

#define PKCR			0xa4050112
#define PKCR_PK0MD0		0x0001
#define PKCR_PK0MD1		0x0002
#define PKCR_PK1MD0		0x0004
#define PKCR_PK1MD1		0x0008
#define PKCR_PK2MD0		0x0010
#define PKCR_PK2MD1		0x0020
#define PKCR_PK3MD0		0x0040
#define PKCR_PK3MD1		0x0080
#define PKCR_PK4MD0		0x0100
#define PKCR_PK4MD1		0x0200

#define HIZCRB			0xa4050158
#define HIZCRB_HIZB4		0x0010

#define	MSELCR			0xa405015c

#define DRVCR			0xa4050180
#define	PFCR			0xa405010a

/* Power down registers */
#define	MSTPCR0			0xa4150030
#define	MSTPCR0_MSTP022		0x00400000
#define	MSTPCR0_MSTP021		0x00200000

#define	MSTPCR2			0xa4150038
#define	MSTPCR2_MSTP208		0x00000100

/* Clock pulse generator registers */
#define	SCLKACR			0xa4150008
#define	SCLKACR_EXSRC		0x00000080
#define	SCLKACR_MCLKSEL		0x00000020

/* SIU registers */
#define IFCTL			0xa454c000
#define SRCTL			0xa454c004
#define SFORM			0xa454c008
#define CKCTL			0xa454c00c
#define TRDAT			0xa454c010
#define SBCTL			0xa454c040
#define SBACTIV			0xa454c074
#define BRGASEL			0xa454c100
#define BRRA			0xa454c104
#define BRGBSEL			0xa454c108
#define BRRB			0xa454c10c


#endif /* SIU_SH7343_H */
